@@ -1,3 +1,4 @@
+import builtins
 import logging
 from collections import OrderedDict
 
@@ -72,7 +73,16 @@ def generate_hotspot_report(sample,
             columns = yaml.load(file, Loader=yaml.FullLoader)
 
     output_order = []
-    hotspot_columns = ['sample', 'chr', 'start', 'stop', 'ref', 'alt', 'report', 'gvcf_depth', 'ref_depth', 'alt_depth']
+    hotspot_columns = {'sample': {},
+                       'chr': {},
+                       'start': {},
+                       'stop': {},
+                       'ref': {},
+                       'alt': {},
+                       'report': {},
+                       'gvcf_depth': {},
+                       'ref_depth': {},
+                       'alt_depth': {}}
     report_header = []
 
     biggest_order = -1
@@ -81,9 +91,12 @@ def generate_hotspot_report(sample,
     if isinstance(columns['columns'], dict):
         gcvf_depth_field = columns['columns'].get('gvcf_depth', {}).get('field', 'DP')
     for entry in columns['columns']:
+        if entry in hotspot_columns:
+            if columns['columns'][entry].get('visible', 1) == 0 or 'order' in columns['columns'][entry]:
+                del hotspot_columns[entry]
+            elif columns['columns'][entry].get('format', None):
+                hotspot_columns[entry]['format'] = columns['columns'][entry]['format']
         if 'order' in columns['columns'][entry]:
-            if entry in hotspot_columns:
-                hotspot_columns.remove(entry)
             output_order.append((columns['columns'][entry]['order'], entry))
             if 'from' in columns['columns'][entry] and 'merge' == columns['columns'][entry]['from']:
                 report_header.append((columns['columns'][entry]['order'],
@@ -93,9 +106,9 @@ def generate_hotspot_report(sample,
             else:
                 report_header.append((columns['columns'][entry]['order'], entry))
             biggest_order = max(biggest_order, columns['columns'][entry]['order'])
-        elif columns['columns'][entry].get('visible', 1) == 0:
-            if entry in hotspot_columns:
-                hotspot_columns.remove(entry)
+    for key in hotspot_columns:
+        if key in columns['columns']:
+            del columns['columns'][key]
 
     for entry in hotspot_columns:
         biggest_order += 1
@@ -156,6 +169,7 @@ def generate_hotspot_report(sample,
                                     'gvcf_depth': depth,
                                     'ref_depth': '-',
                                     'alt_depth': '-'}
+                            format_hotspot(data, columns, hotspot_columns)
                             add_columns(data, None, hotspot, columns, annotation_extractor, depth, levels)
                             writer.write("\n" + "\t".join([str(data[c[1]]) for c in output_order]))
                             counter += 1
@@ -173,6 +187,7 @@ def generate_hotspot_report(sample,
                                     'gvcf_depth': depth,
                                     'ref_depth': var.samples[sample]['AD'][0],
                                     'alt_depth': ",".join(map(str, var.samples[sample]['AD'][1:]))}
+                            format_hotspot(data, columns, hotspot_columns)
                             add_columns(data, var, hotspot, columns, annotation_extractor, depth, levels)
                             writer.write("\n" + "\t".join([str(data[c[1]]) for c in output_order]))
                             counter += 1
@@ -192,12 +207,39 @@ def generate_hotspot_report(sample,
                     'gvcf_depth': depth,
                     'ref_depth': var.samples[sample]['AD'][0],
                     'alt_depth': ",".join(map(str, var.samples[sample]['AD'][1:]))}
+            format_hotspot(data, columns, hotspot_columns)
             add_columns(data, var, None, columns, annotation_extractor, depth, levels)
             writer.write("\n" + "\t".join([str(data[c[1]]) for c in output_order]))
             counter += 1
             log.info("-- non-hotspot entries: {}".format(counter))
 
 
+def format_value(value, format):
+    if format[0] == "replace":
+        return value.replace(format[1], format[2])
+    elif format[0] == "string":
+        if len(format) == 3:
+            value = getattr(builtins, format[2])(value)
+        else:
+            value = float(value)
+        return format[1].format(value)
+    else:
+        raise Exception("Unknown format value: " + format)
+
+
+def format_hotspot(data, columns, hotspot):
+    for key in data:
+        format = columns.get(key, {}).get("format", None)
+        format = hotspot.get(key, {}).get("format", format)
+        if format:
+            try:
+                data[key] = format_value(data[key], format)
+            except ValueError:
+                log.warning("Unable to format value {data[{key}]}, field {key}, format {format}")
+            except TypeError:
+                log.warning("Unable to format value {data[{key}]}, field {key}, format {format}")
+
+
 def extract_item_merge_header(columns):
     header_list = []
     for value in columns:
@@ -258,6 +300,13 @@ def add_columns(data, var, hotspot, columns, annotation_extractor, depth, levels
             data[c] = locals()[column[c]['field']]
         else:
             raise Exception("Undhandledd cased: " + column[c]['field'])
+        if "format" in column[c]:
+            try:
+                data[c] = format_value(data[c], column[c]["format"])
+            except ValueError:
+                log.warning("Unable to format value {data[{c}]}, field {c}, format {column[{c}]['format']}")
+            except TypeError:
+                log.warning("Unable to format value {data[{c}]}, field {c}, format {column[{c}]['format']}")
 
     for c in columns["columns"]:
         if 'from' in columns["columns"][c]:
